@@ -37,7 +37,7 @@ use AnyEvent ();
 use AnyEvent::Handle ();
 use AnyEvent::Util qw(AF_INET6);
 
-our $VERSION = 4.331;
+our $VERSION = 4.34;
 
 our @DNS_FALLBACK = (v208.67.220.220, v208.67.222.222);
 
@@ -1133,14 +1133,12 @@ none on any error or if the name could not be found.
 
 CNAME chains (although illegal) are followed up to a length of 10.
 
-The callback will be invoked with an result code in string form (noerror,
-formerr, servfail, nxdomain, notimp, refused and so on), or numerical
-form if the result code is not supported. The remaining arguments are
-arraryefs of the form C<[$name, $type, $class, @data>], where C<$name> is
-the domain name, C<$type> a type string or number, C<$class> a class name
-and @data is resource-record-dependent data. For C<a> records, this will
-be the textual IPv4 addresses, for C<ns> or C<cname> records this will be
-a domain name, for C<txt> records these are all the strings and so on.
+The callback will be invoked with arraryefs of the form C<[$name, $type,
+$class, @data>], where C<$name> is the domain name, C<$type> a type string
+or number, C<$class> a class name and @data is resource-record-dependent
+data. For C<a> records, this will be the textual IPv4 addresses, for C<ns>
+or C<cname> records this will be a domain name, for C<txt> records these
+are all the strings and so on.
 
 All types mentioned in RFC 1035, C<aaaa>, C<srv>, C<naptr> and C<spf> are
 decoded. All resource records not known to this module will have
