@@ -5,7 +5,7 @@ AnyEvent::Strict - force strict mode on for the whole process
 =head1 SYNOPSIS
 
    use AnyEvent::Strict;
-   # struct mode now switched on
+   # strict mode now switched on
 
 =head1 DESCRIPTION
 
@@ -13,7 +13,7 @@ This module implements AnyEvent's strict mode.
 
 Loading it makes AnyEvent check all arguments to AnyEvent-methods, at the
 expense of being slower (often the argument checking takes longer than the
-actual fucntion).
+actual function).
 
 Normally, you don't load this module yourself but instead use it
 indirectly via the C<PERL_ANYEVENT_STRICT> environment variable (see
@@ -43,7 +43,7 @@ sub io {
       or croak "AnyEvent->io called with illegal cb argument '$arg{cb}'";
    delete $arg{cb};
  
-   fileno $arg{fh}
+   defined fileno $arg{fh}
       or croak "AnyEvent->io called with illegal fh argument '$arg{fh}'";
    delete $arg{fh};
  
